From 5109e91a40640a3ede6853e7d767d3d7a8b17d6f Mon Sep 17 00:00:00 2001
From: Jiangyi Chen <chenjiangyi@uniontech.com>
Date: Tue, 22 Dec 2020 15:36:08 +0800
Subject: [PATCH v2] comctl32/tests: add test for getting listview data during
 sorting.

Signed-off-by: Jiangyi Chen <chenjiangyi@uniontech.com>
---
 dlls/comctl32/tests/listview.c | 58 ++++++++++++++++++++++++++++++++++
 1 file changed, 58 insertions(+)

diff --git a/dlls/comctl32/tests/listview.c b/dlls/comctl32/tests/listview.c
index e95b81f5bb1..9b63afef71a 100644
--- a/dlls/comctl32/tests/listview.c
+++ b/dlls/comctl32/tests/listview.c
@@ -2921,6 +2921,27 @@ static INT WINAPI test_CallBackCompare(LPARAM first, LPARAM second, LPARAM lPara
     return (first > second ? 1 : -1);
 }
 
+static INT WINAPI test_CallBackCompare1(LPARAM first, LPARAM second, LPARAM lParam)
+{
+    if (first == second) return 0;
+    CHAR str1[5];
+    CHAR str2[5];
+    INT  r;
+    HWND hwnd = (HWND)lParam;
+    LV_ITEMA item = {0};
+    item.cchTextMax = 5;
+    item.iSubItem = 0;
+    item.pszText = str1;
+    r = SendMessageA(hwnd, LVM_GETITEMTEXTA, first, (LPARAM)&item);
+    expect(TRUE, r);
+
+    item.pszText = str2;
+    r = SendMessageA(hwnd, LVM_GETITEMTEXTA, second, (LPARAM)&item);
+    expect(TRUE, r);
+
+    return atoi(str1) > atoi(str2)? 1 : -1;
+}
+
 static void test_sorting(void)
 {
     HWND hwnd;
@@ -2928,6 +2949,8 @@ static void test_sorting(void)
     INT r;
     LONG_PTR style;
     static CHAR names[][5] = {"A", "B", "C", "D", "0"};
+    static CHAR before_sort_array[][5] = {"2","3","4","1","6"};
+    static CHAR after_sort_arary[][5] = {"1","2","3","4","6"};
     CHAR buff[10];
 
     hwnd = create_listview_control(LVS_REPORT);
@@ -2979,6 +3002,41 @@ static void test_sorting(void)
 
     DestroyWindow(hwnd);
 
+    hwnd = create_listview_control(LVS_REPORT);
+    ok(hwnd != NULL, "failed to create a listview window\n");
+
+    item.mask = LVIF_PARAM | LVIF_TEXT;
+    item.iSubItem = 0;
+    item.cchTextMax = 5;
+
+    int i = 0;
+    for (i = 0; i < sizeof(before_sort_array)/5; i++)
+    {
+        item.iItem = i;
+        item.lParam = i;
+        item.pszText = &before_sort_array[i][0];
+        r = SendMessageA(hwnd, LVM_INSERTITEMA, 0, (LPARAM) &item);
+        expect(i, r);
+    }
+
+    r = SendMessageA(hwnd, LVM_SORTITEMS, (WPARAM)(LPARAM)hwnd, (LPARAM)test_CallBackCompare1);
+    expect(TRUE, r);
+
+    for (i = 0; i < sizeof(after_sort_arary)/5; i++)
+    {
+        CHAR str[5];
+        item.iItem = i;
+        item.cchTextMax = 5;
+        item.iSubItem = 0;
+        item.pszText = str;
+        r = SendMessageA(hwnd, LVM_GETITEMTEXTA, i, (LPARAM)&item);
+        expect(TRUE, r);
+
+        expect(0, strcmp(str,&after_sort_arary[i][0]));
+    }
+
+    DestroyWindow(hwnd);
+
     /* switch to LVS_SORTASCENDING when some items added */
     hwnd = create_listview_control(LVS_REPORT);
     ok(hwnd != NULL, "failed to create a listview window\n");
-- 
2.20.1

